==> kbear-1.1.tar.gz: kbear-1.1/kbear/kbearquickconnect.h <==
/***************************************************************************
                          kbearquickconnect.h  -  description
                             -------------------
    begin                : Fri Jun 2 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBEAR_QUICKCONNECT_H
#define KBEAR_QUICKCONNECT_H

//////////////////////////////////////////////////////
// Qt specific includes
#include <qwidget.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
#include <kdialog.h>
//////////////////////////////////////////////////////
// Application specific includes
#include "kbearsitemanager.h"
/**
  *@author Bjrn Sahlstrm
  **/

class KBearQuickConnect : public KDialog  {
   Q_OBJECT
public: 
	KBearQuickConnect(QWidget *parent=0, const char *name=0);
	~KBearQuickConnect();
	const bool saveSite() const { return saveToSiteManagerCheckBox->isChecked(); }

signals:
	void remoteConnect( ConnectInfo& );
	void saveToSiteManager( SiteInfo& );
protected slots: // Protected slots
  /** close the quick connect dialog**/
  virtual void reject();
  /** close the quick connect dialog and open a connection to selected host**/
  virtual void accept();

private:
	void initDialog();
	QLabel *UrlLabel;
	QLineEdit *HostNameEdit;
	QLabel *PortLabel;
	QSpinBox *PortSpinBox;
	QLabel *UserNameLabel;
	QLineEdit *UserNameEdit;
	QLabel *PasswordLabel;
	QLineEdit *PasswordEdit;
	QLabel *RemoteDirLabel;
	QLineEdit *RemoteDirEdit;
	QPushButton *ConnectButton;
	QPushButton *CancelButton;
	QCheckBox *AnonymousCheck;
	QCheckBox* saveToSiteManagerCheckBox;
};

#endif

==> kbear_1.2.1.orig.tar.gz: kbear-1.2.1/kbear/kbearquickconnect.h <==
/***************************************************************************
                          kbearquickconnect.h  -  description
                             -------------------
    begin                : Fri Jun 2 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBEAR_QUICKCONNECT_H
#define KBEAR_QUICKCONNECT_H

//////////////////////////////////////////////////////
// Qt specific includes
#include <qwidget.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qspinbox.h>
#include <qpushbutton.h>
#include <qcheckbox.h>
//////////////////////////////////////////////////////
// Application specific includes
#include "kbearsitemanager.h"
#include "kbearquickconnectdialog.h"
/**
  *@author Bjrn Sahlstrm
  **/

class KBearQuickConnect : public KBearQuickConnectDialog  {
   Q_OBJECT
public: 
	KBearQuickConnect(QWidget *parent=0, const char *name=0);
	~KBearQuickConnect();
	const bool saveSite() const { return saveToSiteManagerCheckBox->isChecked(); }

signals:
	void remoteConnect( ConnectInfo&, bool );
	void saveToSiteManager( SiteInfo& );
protected slots: // Protected slots
  /** close the quick connect dialog**/
  virtual void reject();
  /** close the quick connect dialog and open a connection to selected host**/
  virtual void accept();

};

#endif
